# This file was auto-generated by Fern from our API Definition.

import typing
from .dynamic_manager import DynamicManager
from .round_robin_manager import RoundRobinManager
from .supervisor_manager import SupervisorManager

GroupCreateManagerConfig = typing.Union[DynamicManager, RoundRobinManager, SupervisorManager]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_response_agents_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemCreatedById,
)
from .templates_create_agents_response_agents_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_created_at import TemplatesCreateAgentsResponseAgentsItemCreatedAt
from .templates_create_agents_response_agents_item_updated_at import TemplatesCreateAgentsResponseAgentsItemUpdatedAt
from .templates_create_agents_response_agents_item_tool_rules import TemplatesCreateAgentsResponseAgentsItemToolRules
from .templates_create_agents_response_agents_item_message_ids import TemplatesCreateAgentsResponseAgentsItemMessageIds
from .templates_create_agents_response_agents_item_agent_type import TemplatesCreateAgentsResponseAgentsItemAgentType
from .templates_create_agents_response_agents_item_llm_config import TemplatesCreateAgentsResponseAgentsItemLlmConfig
from .templates_create_agents_response_agents_item_embedding_config import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig,
)
from .templates_create_agents_response_agents_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemOrganizationId,
)
from .templates_create_agents_response_agents_item_description import TemplatesCreateAgentsResponseAgentsItemDescription
from .templates_create_agents_response_agents_item_metadata import TemplatesCreateAgentsResponseAgentsItemMetadata
from .templates_create_agents_response_agents_item_memory import TemplatesCreateAgentsResponseAgentsItemMemory
from .templates_create_agents_response_agents_item_tools_item import TemplatesCreateAgentsResponseAgentsItemToolsItem
from .templates_create_agents_response_agents_item_sources_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables,
)
from .templates_create_agents_response_agents_item_project_id import TemplatesCreateAgentsResponseAgentsItemProjectId
from .templates_create_agents_response_agents_item_template_id import TemplatesCreateAgentsResponseAgentsItemTemplateId
from .templates_create_agents_response_agents_item_base_template_id import (
    TemplatesCreateAgentsResponseAgentsItemBaseTemplateId,
)
from .templates_create_agents_response_agents_item_identity_ids import (
    TemplatesCreateAgentsResponseAgentsItemIdentityIds,
)
from .templates_create_agents_response_agents_item_message_buffer_autoclear import (
    TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear,
)
from .templates_create_agents_response_agents_item_multi_agent_group import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItem(UncheckedBaseModel):
    created_by_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemCreatedById] = None
    last_updated_by_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemLastUpdatedById] = None
    created_at: typing.Optional[TemplatesCreateAgentsResponseAgentsItemCreatedAt] = None
    updated_at: typing.Optional[TemplatesCreateAgentsResponseAgentsItemUpdatedAt] = None
    id: str
    name: str
    tool_rules: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolRules] = None
    message_ids: typing.Optional[TemplatesCreateAgentsResponseAgentsItemMessageIds] = None
    system: str
    agent_type: TemplatesCreateAgentsResponseAgentsItemAgentType
    llm_config: TemplatesCreateAgentsResponseAgentsItemLlmConfig
    embedding_config: TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig
    organization_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemOrganizationId] = None
    description: typing.Optional[TemplatesCreateAgentsResponseAgentsItemDescription] = None
    metadata: typing.Optional[TemplatesCreateAgentsResponseAgentsItemMetadata] = None
    memory: TemplatesCreateAgentsResponseAgentsItemMemory
    tools: typing.List[TemplatesCreateAgentsResponseAgentsItemToolsItem]
    sources: typing.List[TemplatesCreateAgentsResponseAgentsItemSourcesItem]
    tags: typing.List[str]
    tool_exec_environment_variables: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables
    ] = None
    project_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemProjectId] = None
    template_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemTemplateId] = None
    base_template_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemBaseTemplateId] = None
    identity_ids: typing.Optional[TemplatesCreateAgentsResponseAgentsItemIdentityIds] = None
    message_buffer_autoclear: typing.Optional[TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear] = None
    multi_agent_group: typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_llm_config_put_inner_thoughts_in_kwargs_item import (
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
)

AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs = typing.Union[
    bool,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_version_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
)

TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from .templates_create_agents_response import TemplatesCreateAgentsResponse
from .templates_create_agents_response_agents_item import TemplatesCreateAgentsResponseAgentsItem
from .templates_create_agents_response_agents_item_agent_type import TemplatesCreateAgentsResponseAgentsItemAgentType
from .templates_create_agents_response_agents_item_base_template_id import (
    TemplatesCreateAgentsResponseAgentsItemBaseTemplateId,
)
from .templates_create_agents_response_agents_item_base_template_id_item import (
    TemplatesCreateAgentsResponseAgentsItemBaseTemplateIdItem,
)
from .templates_create_agents_response_agents_item_created_at import TemplatesCreateAgentsResponseAgentsItemCreatedAt
from .templates_create_agents_response_agents_item_created_at_item import (
    TemplatesCreateAgentsResponseAgentsItemCreatedAtItem,
)
from .templates_create_agents_response_agents_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemCreatedById,
)
from .templates_create_agents_response_agents_item_created_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemCreatedByIdItem,
)
from .templates_create_agents_response_agents_item_description import TemplatesCreateAgentsResponseAgentsItemDescription
from .templates_create_agents_response_agents_item_description_item import (
    TemplatesCreateAgentsResponseAgentsItemDescriptionItem,
)
from .templates_create_agents_response_agents_item_embedding_config import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig,
)
from .templates_create_agents_response_agents_item_embedding_config_azure_deployment import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeployment,
)
from .templates_create_agents_response_agents_item_embedding_config_azure_deployment_item import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
)
from .templates_create_agents_response_agents_item_embedding_config_azure_endpoint import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpoint,
)
from .templates_create_agents_response_agents_item_embedding_config_azure_endpoint_item import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpointItem,
)
from .templates_create_agents_response_agents_item_embedding_config_azure_version import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersion,
)
from .templates_create_agents_response_agents_item_embedding_config_azure_version_item import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersionItem,
)
from .templates_create_agents_response_agents_item_embedding_config_embedding_chunk_size import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
)
from .templates_create_agents_response_agents_item_embedding_config_embedding_chunk_size_item import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .templates_create_agents_response_agents_item_embedding_config_embedding_endpoint import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
)
from .templates_create_agents_response_agents_item_embedding_config_embedding_endpoint_item import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
)
from .templates_create_agents_response_agents_item_embedding_config_embedding_endpoint_type import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
)
from .templates_create_agents_response_agents_item_embedding_config_handle import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandle,
)
from .templates_create_agents_response_agents_item_embedding_config_handle_item import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandleItem,
)
from .templates_create_agents_response_agents_item_identity_ids import (
    TemplatesCreateAgentsResponseAgentsItemIdentityIds,
)
from .templates_create_agents_response_agents_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_last_updated_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemLastUpdatedByIdItem,
)
from .templates_create_agents_response_agents_item_llm_config import TemplatesCreateAgentsResponseAgentsItemLlmConfig
from .templates_create_agents_response_agents_item_llm_config_handle import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigHandle,
)
from .templates_create_agents_response_agents_item_llm_config_handle_item import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigHandleItem,
)
from .templates_create_agents_response_agents_item_llm_config_max_tokens import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokens,
)
from .templates_create_agents_response_agents_item_llm_config_max_tokens_item import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokensItem,
)
from .templates_create_agents_response_agents_item_llm_config_model_endpoint import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpoint,
)
from .templates_create_agents_response_agents_item_llm_config_model_endpoint_item import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointItem,
)
from .templates_create_agents_response_agents_item_llm_config_model_endpoint_type import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointType,
)
from .templates_create_agents_response_agents_item_llm_config_model_wrapper import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapper,
)
from .templates_create_agents_response_agents_item_llm_config_model_wrapper_item import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapperItem,
)
from .templates_create_agents_response_agents_item_llm_config_put_inner_thoughts_in_kwargs import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
)
from .templates_create_agents_response_agents_item_llm_config_put_inner_thoughts_in_kwargs_item import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
)
from .templates_create_agents_response_agents_item_llm_config_temperature import (
    TemplatesCreateAgentsResponseAgentsItemLlmConfigTemperature,
)
from .templates_create_agents_response_agents_item_memory import TemplatesCreateAgentsResponseAgentsItemMemory
from .templates_create_agents_response_agents_item_memory_blocks_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItem,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedById,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_created_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_description import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescription,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_description_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescriptionItem,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_id import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemId,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_is_template import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemIsTemplate,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_label import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabel,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_label_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabelItem,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_last_updated_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_limit import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLimit,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_metadata import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadata,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_metadata_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadataItem,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_name import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemName,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_name_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemNameItem,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationId,
)
from .templates_create_agents_response_agents_item_memory_blocks_item_organization_id_item import (
    TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
)
from .templates_create_agents_response_agents_item_memory_prompt_template import (
    TemplatesCreateAgentsResponseAgentsItemMemoryPromptTemplate,
)
from .templates_create_agents_response_agents_item_message_buffer_autoclear import (
    TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear,
)
from .templates_create_agents_response_agents_item_message_ids import TemplatesCreateAgentsResponseAgentsItemMessageIds
from .templates_create_agents_response_agents_item_message_ids_item import (
    TemplatesCreateAgentsResponseAgentsItemMessageIdsItem,
)
from .templates_create_agents_response_agents_item_metadata import TemplatesCreateAgentsResponseAgentsItemMetadata
from .templates_create_agents_response_agents_item_metadata_item import (
    TemplatesCreateAgentsResponseAgentsItemMetadataItem,
)
from .templates_create_agents_response_agents_item_multi_agent_group import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids_manager_agent_id import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentId,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids_manager_agent_id_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentIdItem,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids_manager_type import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerType,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids_max_turns import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurns,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids_max_turns_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurnsItem,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids_termination_token import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationToken,
)
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids_termination_token_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationTokenItem,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_manager_agent_id import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_manager_agent_id_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentIdItem,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_manager_type import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_max_turns import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_max_turns_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_termination_token import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_termination_token_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem,
)
from .templates_create_agents_response_agents_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemOrganizationId,
)
from .templates_create_agents_response_agents_item_organization_id_item import (
    TemplatesCreateAgentsResponseAgentsItemOrganizationIdItem,
)
from .templates_create_agents_response_agents_item_project_id import TemplatesCreateAgentsResponseAgentsItemProjectId
from .templates_create_agents_response_agents_item_project_id_item import (
    TemplatesCreateAgentsResponseAgentsItemProjectIdItem,
)
from .templates_create_agents_response_agents_item_sources_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItem,
)
from .templates_create_agents_response_agents_item_sources_item_created_at import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAt,
)
from .templates_create_agents_response_agents_item_sources_item_created_at_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAtItem,
)
from .templates_create_agents_response_agents_item_sources_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedById,
)
from .templates_create_agents_response_agents_item_sources_item_created_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedByIdItem,
)
from .templates_create_agents_response_agents_item_sources_item_description import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemDescription,
)
from .templates_create_agents_response_agents_item_sources_item_description_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemDescriptionItem,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfig,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_deployment import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_deployment_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_endpoint_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_version import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_version_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_chunk_size_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_endpoint_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_handle import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_handle_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
)
from .templates_create_agents_response_agents_item_sources_item_id import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemId,
)
from .templates_create_agents_response_agents_item_sources_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_sources_item_last_updated_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedByIdItem,
)
from .templates_create_agents_response_agents_item_sources_item_metadata import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadata,
)
from .templates_create_agents_response_agents_item_sources_item_metadata_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadataItem,
)
from .templates_create_agents_response_agents_item_sources_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationId,
)
from .templates_create_agents_response_agents_item_sources_item_organization_id_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationIdItem,
)
from .templates_create_agents_response_agents_item_sources_item_updated_at import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAt,
)
from .templates_create_agents_response_agents_item_sources_item_updated_at_item import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAtItem,
)
from .templates_create_agents_response_agents_item_template_id import TemplatesCreateAgentsResponseAgentsItemTemplateId
from .templates_create_agents_response_agents_item_template_id_item import (
    TemplatesCreateAgentsResponseAgentsItemTemplateIdItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_at import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_at_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_description import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_description_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_organization_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_updated_at_item import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
)
from .templates_create_agents_response_agents_item_tool_rules import TemplatesCreateAgentsResponseAgentsItemToolRules
from .templates_create_agents_response_agents_item_tool_rules_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItem,
)
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMapping,
)
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping_default_child import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
)
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping_default_child_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
)
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping_require_output_mapping import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
)
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_children import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildren,
)
from .templates_create_agents_response_agents_item_tool_rules_item_children_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildrenType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_four import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemFour,
)
from .templates_create_agents_response_agents_item_tool_rules_item_four_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemFourType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_child_output_mapping import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMapping,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_child_output_mapping_default_child import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_child_output_mapping_default_child_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_child_output_mapping_require_output_mapping import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_child_output_mapping_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_children import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildren,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_children_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildrenType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_four import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFour,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_four_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFourType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_max_count_limit import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimit,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_max_count_limit_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimitType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_one import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOne,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_one_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_two import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwo,
)
from .templates_create_agents_response_agents_item_tool_rules_item_item_two_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwoType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_max_count_limit import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimit,
)
from .templates_create_agents_response_agents_item_tool_rules_item_max_count_limit_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimitType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_one import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemOne,
)
from .templates_create_agents_response_agents_item_tool_rules_item_one_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemOneType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_two import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwo,
)
from .templates_create_agents_response_agents_item_tool_rules_item_two_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwoType,
)
from .templates_create_agents_response_agents_item_tools_item import TemplatesCreateAgentsResponseAgentsItemToolsItem
from .templates_create_agents_response_agents_item_tools_item_args_json_schema import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchema,
)
from .templates_create_agents_response_agents_item_tools_item_args_json_schema_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchemaItem,
)
from .templates_create_agents_response_agents_item_tools_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById,
)
from .templates_create_agents_response_agents_item_tools_item_created_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedByIdItem,
)
from .templates_create_agents_response_agents_item_tools_item_description import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemDescription,
)
from .templates_create_agents_response_agents_item_tools_item_description_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemDescriptionItem,
)
from .templates_create_agents_response_agents_item_tools_item_json_schema import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema,
)
from .templates_create_agents_response_agents_item_tools_item_json_schema_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchemaItem,
)
from .templates_create_agents_response_agents_item_tools_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_tools_item_last_updated_by_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem,
)
from .templates_create_agents_response_agents_item_tools_item_metadata import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemMetadata,
)
from .templates_create_agents_response_agents_item_tools_item_metadata_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemMetadataItem,
)
from .templates_create_agents_response_agents_item_tools_item_name import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemName,
)
from .templates_create_agents_response_agents_item_tools_item_name_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem,
)
from .templates_create_agents_response_agents_item_tools_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId,
)
from .templates_create_agents_response_agents_item_tools_item_organization_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem,
)
from .templates_create_agents_response_agents_item_tools_item_source_code import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode,
)
from .templates_create_agents_response_agents_item_tools_item_source_code_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCodeItem,
)
from .templates_create_agents_response_agents_item_tools_item_source_type import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType,
)
from .templates_create_agents_response_agents_item_tools_item_source_type_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceTypeItem,
)
from .templates_create_agents_response_agents_item_tools_item_tool_type import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemToolType,
)
from .templates_create_agents_response_agents_item_updated_at import TemplatesCreateAgentsResponseAgentsItemUpdatedAt
from .templates_create_agents_response_agents_item_updated_at_item import (
    TemplatesCreateAgentsResponseAgentsItemUpdatedAtItem,
)

__all__ = [
    "TemplatesCreateAgentsResponse",
    "TemplatesCreateAgentsResponseAgentsItem",
    "TemplatesCreateAgentsResponseAgentsItemAgentType",
    "TemplatesCreateAgentsResponseAgentsItemBaseTemplateId",
    "TemplatesCreateAgentsResponseAgentsItemBaseTemplateIdItem",
    "TemplatesCreateAgentsResponseAgentsItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfig",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemIdentityIds",
    "TemplatesCreateAgentsResponseAgentsItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfig",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokens",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigMaxTokensItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapper",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigModelWrapperItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "TemplatesCreateAgentsResponseAgentsItemLlmConfigTemperature",
    "TemplatesCreateAgentsResponseAgentsItemMemory",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemId",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemIsTemplate",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabel",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLabelItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemLimit",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemName",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemNameItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMemoryPromptTemplate",
    "TemplatesCreateAgentsResponseAgentsItemMessageBufferAutoclear",
    "TemplatesCreateAgentsResponseAgentsItemMessageIds",
    "TemplatesCreateAgentsResponseAgentsItemMessageIdsItem",
    "TemplatesCreateAgentsResponseAgentsItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentId",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerAgentIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerType",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurns",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsMaxTurnsItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationToken",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsTerminationTokenItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentIdItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurnsItem",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken",
    "TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem",
    "TemplatesCreateAgentsResponseAgentsItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemProjectId",
    "TemplatesCreateAgentsResponseAgentsItemProjectIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfig",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemId",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemSourcesItemUpdatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemTemplateId",
    "TemplatesCreateAgentsResponseAgentsItemTemplateIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariables",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRules",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildren",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildrenType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemFour",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemFourType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildren",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildrenType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFour",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemFourType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimit",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemMaxCountLimitType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOne",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemOneType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwo",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemTwoType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimit",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimitType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemOne",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemOneType",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwo",
    "TemplatesCreateAgentsResponseAgentsItemToolRulesItemTwoType",
    "TemplatesCreateAgentsResponseAgentsItemToolsItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchema",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchemaItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemDescription",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemDescriptionItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchemaItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemMetadata",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemMetadataItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemName",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCodeItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemSourceTypeItem",
    "TemplatesCreateAgentsResponseAgentsItemToolsItemToolType",
    "TemplatesCreateAgentsResponseAgentsItemUpdatedAt",
    "TemplatesCreateAgentsResponseAgentsItemUpdatedAtItem",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
import typing
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_handle import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_version import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .templates_create_agents_response_agents_item_sources_item_embedding_config_azure_deployment import (
    TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfig(UncheckedBaseModel):
    embedding_endpoint_type: TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType
    embedding_endpoint: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint
    ] = None
    embedding_model: str
    embedding_dim: float
    embedding_chunk_size: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize
    ] = None
    handle: typing.Optional[TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigHandle] = None
    azure_endpoint: typing.Optional[TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint] = (
        None
    )
    azure_version: typing.Optional[TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion] = None
    azure_deployment: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds,
)

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem = typing.Union[
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds, typing.Optional[str]
]



# This file was auto-generated by Fern from our API Definition.

from .conflict_error import ConflictError
from .internal_server_error import InternalServerError
from .not_found_error import NotFoundError
from .unprocessable_entity_error import UnprocessableEntityError

__all__ = ["ConflictError", "InternalServerError", "NotFoundError", "UnprocessableEntityError"]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tool_rules_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItem,
)

TemplatesCreateAgentsResponseAgentsItemToolRules = typing.Union[
    typing.List[TemplatesCreateAgentsResponseAgentsItemToolRulesItem],
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolRulesItem]],
    typing.Optional[typing.Any],
]
